pitchtools.PitchClassObject
===========================

.. abjad-lineage:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject

.. autoclass:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__ge__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__gt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__le__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__lt__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchClassObject.PitchClassObject.PitchClassObject.__repr__
   :noindex:
